@@ -2,8 +2,6 @@
 
 static LFT_CALLBACK LFTErrHandler = NULL;
 static LFT_CALLBACK LFTEvtHandler = NULL;
-extern const char *version;
-extern const char *appname;
 
 unsigned int icmp_rfc_send_request(lft_session_params * sess, LFT_CALLBACK err, LFT_CALLBACK evt);
 unsigned int icmp_base_send_hop(lft_session_params * sess, LFT_CALLBACK err, LFT_CALLBACK evt, short nhop);
@@ -51,7 +49,7 @@ struct icmp_trace_packet_s
 #ifndef IPDEFTTL
 #define IPDEFTTL 200
 #endif
-char payload_fill[]="VOSTROM";
+static const char payload_fill[]="VOSTROM";
 int generateICMPPacket(
 	lft_session_params * sess, 
 	LFT_CALLBACK err, 
