@@ -48,6 +48,7 @@
 /* OPTIONS and variable initialization */
 
 static char pwhois_server[] = "whois.pwhois.org";
+static char myaddress_server[] = "myaddress.today";
 static char radb_server[] = "whois.ra.net";
 static char cymru_server[] = "whois.cymru.com";
 static char arin_server[] = "whois.arin.net";
@@ -56,8 +57,8 @@ static char ripe_server[] = "whois.ripe.net";
 static char ripe_ris_server[] = "riswhois.ripe.net";
 
 #ifdef STANDALONE
-const char *version = "3.77";                   /* set version string for library and client */
-const char *appname = "WhoB";            	    /* set application name */
+const char *version = "3.91";                   /* set version string for library and client */
+const char *appname = "WhoB";                   /* set application name */
 static int go_interactive = 0;                  /* We'll wait on STDIN unless args suggest otherwise */
 static int use_cymru = 0;                       /* Don't use Cymru by default */
 static int use_riswhois = 0;                    /* Don't use RIPE NCC RIS by default */
@@ -1567,6 +1568,58 @@ static int w_display_pwhois_version(whois_session_params * wsess)
     return 0;
 }
 
+static int w_display_myaddress_http(whois_session_params * wsess)
+{
+    char *reply;
+    char *serv;
+
+    if (strlen(wsess->pw_serv) > 0)
+        serv = wsess->pw_serv;
+    else
+        serv = myaddress_server;
+
+    if (wsess->w_noisy)
+        fprintf(stderr,"Querying '%s' for my public address.\n",serv);
+
+    reply = w_ask(serv, "Accept:*/*\nHost: myaddress.today\nUser-Agent: WhoB\nGET /\n\n", "80");
+    if (!reply) {
+        if(wsess->w_noisy)
+                fprintf(stderr,"No reply from %s.\n",serv);
+        return -1;
+    }
+  
+    printf("%s",reply);
+
+    free(reply);
+    return 0;
+}
+
+static int w_display_myaddress(whois_session_params * wsess)
+{
+    char *reply;
+    char *serv;
+
+    if (strlen(wsess->pw_serv) > 0)
+        serv = wsess->pw_serv;
+    else
+        serv = pwhois_server;
+
+    if (wsess->w_noisy)
+        fprintf(stderr,"Querying '%s' for my public address.\n",serv);
+
+    reply = w_ask(serv, "whoami", NULL);
+    if (!reply) {
+        if(wsess->w_noisy)
+                fprintf(stderr,"No reply from %s.\n",serv);
+        return -1;
+    }
+   
+    printf("%s",reply);
+
+    free(reply);
+    return 0;
+}
+
 static int w_display_pwhois_gigo(whois_session_params * wsess, char *user_query)
 {
     char *reply;
@@ -2344,6 +2397,7 @@ usage (char *prog)
              "  -s         Display the version and status of the pWhoIs server (pWhoIs-only)\n"
              "  -V         Display verbose/debug output.  Use more \'V\'s for additional detail\n"
              "  -v         Display WhoB\'s version information and exit\n"  
+             "  me|whoami  Display the public IP address of this host\n"
              "\n"
              ,version,prog);
     fprintf(stderr,"Example:     %s -gnp 1.2.3.4\n",prog);
@@ -2588,8 +2642,14 @@ int main(int ac, char **av)
     }
     
     if (use_gigo > 0) {
-        w_display_pwhois_gigo(wsess, hostname);
-        exit(EXIT_SUCCESS);
+
+        if (strncmp(hostname,"me",2) == 0 || strncmp(hostname,"whoami",6) == 0) {
+            w_display_myaddress(wsess);
+            exit(EXIT_SUCCESS);
+        } else {
+           w_display_pwhois_gigo(wsess, hostname);
+           exit(EXIT_SUCCESS);
+	}
     }
     
     if ((show_routes_byasn || show_routes_bytransitasn || show_contacts_byasn || show_networks_byasn) && (strlen(hostname) <= 10) && atoi(hostname) && stricontains(hostname,".") < 1) {
@@ -2598,6 +2658,11 @@ int main(int ac, char **av)
     } else if (show_routes_byprefix == 1) {
         printf("Displaying all routes for prefix %s.\n",hostname);
     } else {
+
+	if (strncmp(hostname,"me",2) == 0 || strncmp(hostname,"whoami",6) == 0) {
+	    w_display_myaddress(wsess);
+	    exit(EXIT_SUCCESS);
+	}
         
         if (inet_aton(hostname, &in)) {
             addr = hostname;
